@@ -11,9 +11,14 @@ year = units.year.to('s')
 gauss = units.gauss.to('T')
 cm = units.cm.to('m')
 km = units.km.to('m')
+angstrom = units.angstrom.to('m')
 gram = units.gram.to('kg')
 debye = units.debye.to('A*s*m')
 erg = units.erg.to('J')
+coulomb = units.coulomb.to('A*s')
+newton = units.newton.to('kg*m*s**(-2)')
+pascal = units.pascal.to('J*m**(-3)')
+watt = units.watt.to('J*s**(-1)')
 
 # astropy.constants in the SI unit system
 G = constants.G.si.value
@@ -81,4 +86,4 @@ quecto = 1e-30
 # Others
 mumol = 2.37 * m_p  # kg; Kauffmann et al. 2008, for sound speed
 muH2 = 2.8 * m_p  # kg; Kauffmann et al. 2008, for mass-H2 conversion
-c_kms = constants.c.to('km*s**(-1)').value
\ No newline at end of file
+c_kms = constants.c.to('km*s**(-1)').value
